@@ -1,8 +1,8 @@
+# from datetime import datetime
 from colorama import Style, Fore
 from functools import wraps
 from typing import Union
 from copy import deepcopy
-from datetime import datetime
 
 
 class TouchlineData:
@@ -149,7 +149,7 @@ class TickLiveData:
         except Exception as e:
             raise TDLiveCalcError(f"Encountered other change calculation error: {e} with symbol {self.symbol} with tick_type={self.tick_type} and tick_seq={self.tick_seq}")
         finally:
-            return self._oi_change_perc
+            return self._change_perc
 
 
 class MinLiveData:
@@ -243,7 +243,7 @@ class MinLiveData:
         except Exception as e:
             raise TDLiveCalcError(f"Encountered other change calculation error: {e} with symbol {self.symbol} with timestamp={self.timestamp}")
         finally:
-            return self._oi_change_perc
+            return self._change_perc
 
 
 def populate_touchline_data(data_obj: Union[TickLiveData, MinLiveData], touchline_obj: TouchlineData):
@@ -264,6 +264,7 @@ def populate_touchline_data(data_obj: Union[TickLiveData, MinLiveData], touchlin
         data_obj.close = touchline_obj.ltp
 
 
+
 class TDLiveCalcError(Exception):
     def __str__(self):
         return f"{Style.BRIGHT}{Fore.RED}Something's wrong with the live calculations- {self.args[0]}{Style.RESET_ALL}"
@@ -286,35 +287,30 @@ class TDInvalidRequestError(Exception):
 
 def historical_decorator(func):
     @wraps(func)
-    def dec_helper(obj, contract, end_time, start_time, bar_size, options=None, bidask=False):
-        if not options:
-            options = {}
-        if bar_size.lower() == 'tick' or bar_size.lower() == 'ticks':
+    def dec_helper(obj, contract, end_time, start_time, bar_size, options=None):
+        options = {}
+        if bar_size.lower() == 'tick':
             bar_size = 'tick'
-            options['time_format'] = '%Y-%m-%dT%H:%M:%S'  # This is the response format
-            options['processor_to_call'] = {'csv': obj.hist_csv_tick_data_to_dict_list, 'json': obj.hist_json_tick_data_to_dict_list}
+            options['time_format'] = '%Y-%m-%dT%H:%M:%S'
+            options['processor_to_call'] = obj.hist_tick_data_to_dict_list
         elif bar_size.lower() == 'eod':
-            # start_time = start_time.split('T')[0]
-            # end_time = end_time.split('T')[0]
-            bar_size = 'eod'
-            options['time_format'] = '%Y-%m-%d'  # This is the response format
-            # options['time_format'] = '%Y-%m-%dT%H:%M:%S'  # This is the response format
-            options['processor_to_call'] = {'csv': obj.hist_csv_bar_data_to_dict_list, 'json': obj.hist_json_bar_data_to_dict_list}
+            start_time = start_time.split('T')[0]
+            end_time = end_time.split('T')[0]
+            bar_size = 'EOD'
+            options['time_format'] = '%Y-%m-%d'
+            options['processor_to_call'] = obj.hist_bar_data_to_dict_list
         else:
             bar_size = bar_size.replace(' ', '')
             if bar_size[-1] == 's':
                 bar_size = bar_size[:-1]
-            options['time_format'] = '%Y-%m-%dT%H:%M:%S'  # This is the response format
-            options['processor_to_call'] = {'csv': obj.hist_csv_bar_data_to_dict_list, 'json': obj.hist_json_bar_data_to_dict_list}
-        return func(obj, contract, end_time, start_time, bar_size, options, bidask)
-
+            options['time_format'] = '%Y-%m-%dT%H:%M:%S'
+            options['processor_to_call'] = obj.hist_bar_data_to_dict_list
+        return func(obj, contract, end_time, start_time, bar_size, options)
     return dec_helper
 
-
-def access_token_decorator(func):
-    @wraps(func)
-    def dec_helper(obj, *args, **kwargs):
-        if obj.access_token_expiry_time < datetime.now():
-            obj.hist_login()
-        return func(obj, *args, **kwargs)
-    return dec_helper
+# def historical_reconnect_on_failure(func):
+#     @wraps(func)
+#     def wrapper_func(*args, **kwargs):
+#         try:
+#             return func(*args, **kwargs)
+#         except ConnectionResetError:
